@@ -1,5 +1,4 @@
 use assert_matches::assert_matches;
-use prae::Guard;
 
 prae::define! {
     pub Username: String
@@ -22,21 +21,14 @@ fn construction_succeeds_for_valid_data() {
 fn mutation_fails_for_invalid_data() {
     let mut un = Username::new("user").unwrap();
     assert_matches!(
-        un.try_mutate(|u| *u = "  ".to_owned()),
+        un.mutate(|u| *u = "  ".to_owned()),
         Err(prae::MutationError { .. })
     )
 }
 
-#[test]
-#[should_panic]
-fn mutation_panics_for_invalid_data() {
-    let mut un = Username::new("user").unwrap();
-    un.mutate(|u| *u = "  ".to_owned());
-}
-
 #[test]
 fn mutation_succeeds_for_valid_data() {
     let mut un = Username::new("user").unwrap();
-    assert!(un.try_mutate(|u| *u = "  new user  ".to_owned()).is_ok());
+    un.mutate(|u| *u = "  new user  ".to_owned()).unwrap();
     assert_eq!(un.get(), "new user");
 }
